#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['sigdepsem']

package_data = \
{'': ['*']}

extras_require = \
{'test': ['pytest', 'pytest-runner']}

setup(name='sigdepsem',
      version='0.1',
      description='Demonstrate signature dependent semantics for item get, set, del',
      author='Rick L Teachey Jr',
      author_email='ricky@teachey.org',
      url=None,
      packages=packages,
      package_data=package_data,
      extras_require=extras_require,
     )
